lfppb

package
v1.4.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Dec 4, 2025 License: Apache-2.0 Imports: 12 Imported by: 0

Documentation

Index

Constants

const (
	LfpStoreService_GetLfpStore_FullMethodName    = "/google.shopping.merchant.lfp.v1beta.LfpStoreService/GetLfpStore"
	LfpStoreService_InsertLfpStore_FullMethodName = "/google.shopping.merchant.lfp.v1beta.LfpStoreService/InsertLfpStore"
	LfpStoreService_DeleteLfpStore_FullMethodName = "/google.shopping.merchant.lfp.v1beta.LfpStoreService/DeleteLfpStore"
	LfpStoreService_ListLfpStores_FullMethodName  = "/google.shopping.merchant.lfp.v1beta.LfpStoreService/ListLfpStores"
)
const (
	LfpInventoryService_InsertLfpInventory_FullMethodName = "/google.shopping.merchant.lfp.v1beta.LfpInventoryService/InsertLfpInventory"
)
const (
	LfpMerchantStateService_GetLfpMerchantState_FullMethodName = "/google.shopping.merchant.lfp.v1beta.LfpMerchantStateService/GetLfpMerchantState"
)
const (
	LfpSaleService_InsertLfpSale_FullMethodName = "/google.shopping.merchant.lfp.v1beta.LfpSaleService/InsertLfpSale"
)

Variables

var (
	LfpMerchantState_LfpStoreState_StoreMatchingState_name = map[int32]string{
		0: "STORE_MATCHING_STATE_UNSPECIFIED",
		1: "STORE_MATCHING_STATE_MATCHED",
		2: "STORE_MATCHING_STATE_FAILED",
	}
	LfpMerchantState_LfpStoreState_StoreMatchingState_value = map[string]int32{
		"STORE_MATCHING_STATE_UNSPECIFIED": 0,
		"STORE_MATCHING_STATE_MATCHED":     1,
		"STORE_MATCHING_STATE_FAILED":      2,
	}
)

Enum value maps for LfpMerchantState_LfpStoreState_StoreMatchingState.

var (
	LfpMerchantState_CountrySettings_VerificationState_name = map[int32]string{
		0: "VERIFICATION_STATE_UNSPECIFIED",
		1: "VERIFICATION_STATE_NOT_APPROVED",
		2: "VERIFICATION_STATE_IN_PROGRESS",
		3: "VERIFICATION_STATE_APPROVED",
	}
	LfpMerchantState_CountrySettings_VerificationState_value = map[string]int32{
		"VERIFICATION_STATE_UNSPECIFIED":  0,
		"VERIFICATION_STATE_NOT_APPROVED": 1,
		"VERIFICATION_STATE_IN_PROGRESS":  2,
		"VERIFICATION_STATE_APPROVED":     3,
	}
)

Enum value maps for LfpMerchantState_CountrySettings_VerificationState.

var (
	LfpMerchantState_CountrySettings_ProductPageType_name = map[int32]string{
		0: "PRODUCT_PAGE_TYPE_UNSPECIFIED",
		1: "GOOGLE_HOSTED",
		2: "MERCHANT_HOSTED",
		3: "MERCHANT_HOSTED_STORE_SPECIFIC",
	}
	LfpMerchantState_CountrySettings_ProductPageType_value = map[string]int32{
		"PRODUCT_PAGE_TYPE_UNSPECIFIED":  0,
		"GOOGLE_HOSTED":                  1,
		"MERCHANT_HOSTED":                2,
		"MERCHANT_HOSTED_STORE_SPECIFIC": 3,
	}
)

Enum value maps for LfpMerchantState_CountrySettings_ProductPageType.

var (
	LfpStore_StoreMatchingState_name = map[int32]string{
		0: "STORE_MATCHING_STATE_UNSPECIFIED",
		1: "STORE_MATCHING_STATE_MATCHED",
		2: "STORE_MATCHING_STATE_FAILED",
	}
	LfpStore_StoreMatchingState_value = map[string]int32{
		"STORE_MATCHING_STATE_UNSPECIFIED": 0,
		"STORE_MATCHING_STATE_MATCHED":     1,
		"STORE_MATCHING_STATE_FAILED":      2,
	}
)

Enum value maps for LfpStore_StoreMatchingState.

var File_google_shopping_merchant_lfp_v1beta_lfpinventory_proto protoreflect.FileDescriptor
var File_google_shopping_merchant_lfp_v1beta_lfpmerchantstate_proto protoreflect.FileDescriptor
var File_google_shopping_merchant_lfp_v1beta_lfpsale_proto protoreflect.FileDescriptor
var File_google_shopping_merchant_lfp_v1beta_lfpstore_proto protoreflect.FileDescriptor
var LfpInventoryService_ServiceDesc = grpc.ServiceDesc{
	ServiceName: "google.shopping.merchant.lfp.v1beta.LfpInventoryService",
	HandlerType: (*LfpInventoryServiceServer)(nil),
	Methods: []grpc.MethodDesc{
		{
			MethodName: "InsertLfpInventory",
			Handler:    _LfpInventoryService_InsertLfpInventory_Handler,
		},
	},
	Streams:  []grpc.StreamDesc{},
	Metadata: "google/shopping/merchant/lfp/v1beta/lfpinventory.proto",
}

LfpInventoryService_ServiceDesc is the grpc.ServiceDesc for LfpInventoryService service. It's only intended for direct use with grpc.RegisterService, and not to be introspected or modified (even as a copy)

var LfpMerchantStateService_ServiceDesc = grpc.ServiceDesc{
	ServiceName: "google.shopping.merchant.lfp.v1beta.LfpMerchantStateService",
	HandlerType: (*LfpMerchantStateServiceServer)(nil),
	Methods: []grpc.MethodDesc{
		{
			MethodName: "GetLfpMerchantState",
			Handler:    _LfpMerchantStateService_GetLfpMerchantState_Handler,
		},
	},
	Streams:  []grpc.StreamDesc{},
	Metadata: "google/shopping/merchant/lfp/v1beta/lfpmerchantstate.proto",
}

LfpMerchantStateService_ServiceDesc is the grpc.ServiceDesc for LfpMerchantStateService service. It's only intended for direct use with grpc.RegisterService, and not to be introspected or modified (even as a copy)

var LfpSaleService_ServiceDesc = grpc.ServiceDesc{
	ServiceName: "google.shopping.merchant.lfp.v1beta.LfpSaleService",
	HandlerType: (*LfpSaleServiceServer)(nil),
	Methods: []grpc.MethodDesc{
		{
			MethodName: "InsertLfpSale",
			Handler:    _LfpSaleService_InsertLfpSale_Handler,
		},
	},
	Streams:  []grpc.StreamDesc{},
	Metadata: "google/shopping/merchant/lfp/v1beta/lfpsale.proto",
}

LfpSaleService_ServiceDesc is the grpc.ServiceDesc for LfpSaleService service. It's only intended for direct use with grpc.RegisterService, and not to be introspected or modified (even as a copy)

var LfpStoreService_ServiceDesc = grpc.ServiceDesc{
	ServiceName: "google.shopping.merchant.lfp.v1beta.LfpStoreService",
	HandlerType: (*LfpStoreServiceServer)(nil),
	Methods: []grpc.MethodDesc{
		{
			MethodName: "GetLfpStore",
			Handler:    _LfpStoreService_GetLfpStore_Handler,
		},
		{
			MethodName: "InsertLfpStore",
			Handler:    _LfpStoreService_InsertLfpStore_Handler,
		},
		{
			MethodName: "DeleteLfpStore",
			Handler:    _LfpStoreService_DeleteLfpStore_Handler,
		},
		{
			MethodName: "ListLfpStores",
			Handler:    _LfpStoreService_ListLfpStores_Handler,
		},
	},
	Streams:  []grpc.StreamDesc{},
	Metadata: "google/shopping/merchant/lfp/v1beta/lfpstore.proto",
}

LfpStoreService_ServiceDesc is the grpc.ServiceDesc for LfpStoreService service. It's only intended for direct use with grpc.RegisterService, and not to be introspected or modified (even as a copy)

Functions

func RegisterLfpInventoryServiceServer

func RegisterLfpInventoryServiceServer(s grpc.ServiceRegistrar, srv LfpInventoryServiceServer)

func RegisterLfpMerchantStateServiceServer added in v0.19.0

func RegisterLfpMerchantStateServiceServer(s grpc.ServiceRegistrar, srv LfpMerchantStateServiceServer)

func RegisterLfpSaleServiceServer

func RegisterLfpSaleServiceServer(s grpc.ServiceRegistrar, srv LfpSaleServiceServer)

func RegisterLfpStoreServiceServer

func RegisterLfpStoreServiceServer(s grpc.ServiceRegistrar, srv LfpStoreServiceServer)

Types

type DeleteLfpStoreRequest

type DeleteLfpStoreRequest struct {

	// Required. The name of the store to delete for the target merchant account.
	// Format: `accounts/{account}/lfpStores/{target_merchant}~{store_code}`
	Name string `protobuf:"bytes,1,opt,name=name,proto3" json:"name,omitempty"`
	// contains filtered or unexported fields
}

Request message for the DeleteLfpStore method.

func (*DeleteLfpStoreRequest) Descriptor deprecated

func (*DeleteLfpStoreRequest) Descriptor() ([]byte, []int)

Deprecated: Use DeleteLfpStoreRequest.ProtoReflect.Descriptor instead.

func (*DeleteLfpStoreRequest) GetName

func (x *DeleteLfpStoreRequest) GetName() string

func (*DeleteLfpStoreRequest) ProtoMessage

func (*DeleteLfpStoreRequest) ProtoMessage()

func (*DeleteLfpStoreRequest) ProtoReflect

func (x *DeleteLfpStoreRequest) ProtoReflect() protoreflect.Message

func (*DeleteLfpStoreRequest) Reset

func (x *DeleteLfpStoreRequest) Reset()

func (*DeleteLfpStoreRequest) String

func (x *DeleteLfpStoreRequest) String() string

type GetLfpMerchantStateRequest added in v0.19.0

type GetLfpMerchantStateRequest struct {

	// Required. The name of the state to retrieve.
	// Format: `accounts/{account}/lfpMerchantStates/{target_merchant}`
	Name string `protobuf:"bytes,1,opt,name=name,proto3" json:"name,omitempty"`
	// contains filtered or unexported fields
}

Request message for the GetLfpMerchantState method.

func (*GetLfpMerchantStateRequest) Descriptor deprecated added in v0.19.0

func (*GetLfpMerchantStateRequest) Descriptor() ([]byte, []int)

Deprecated: Use GetLfpMerchantStateRequest.ProtoReflect.Descriptor instead.

func (*GetLfpMerchantStateRequest) GetName added in v0.19.0

func (x *GetLfpMerchantStateRequest) GetName() string

func (*GetLfpMerchantStateRequest) ProtoMessage added in v0.19.0

func (*GetLfpMerchantStateRequest) ProtoMessage()

func (*GetLfpMerchantStateRequest) ProtoReflect added in v0.19.0

func (*GetLfpMerchantStateRequest) Reset added in v0.19.0

func (x *GetLfpMerchantStateRequest) Reset()

func (*GetLfpMerchantStateRequest) String added in v0.19.0

func (x *GetLfpMerchantStateRequest) String() string

type GetLfpStoreRequest

type GetLfpStoreRequest struct {

	// Required. The name of the store to retrieve.
	// Format: `accounts/{account}/lfpStores/{target_merchant}~{store_code}`
	Name string `protobuf:"bytes,1,opt,name=name,proto3" json:"name,omitempty"`
	// contains filtered or unexported fields
}

Request message for the `GetLfpStore` method.

func (*GetLfpStoreRequest) Descriptor deprecated

func (*GetLfpStoreRequest) Descriptor() ([]byte, []int)

Deprecated: Use GetLfpStoreRequest.ProtoReflect.Descriptor instead.

func (*GetLfpStoreRequest) GetName

func (x *GetLfpStoreRequest) GetName() string

func (*GetLfpStoreRequest) ProtoMessage

func (*GetLfpStoreRequest) ProtoMessage()

func (*GetLfpStoreRequest) ProtoReflect

func (x *GetLfpStoreRequest) ProtoReflect() protoreflect.Message

func (*GetLfpStoreRequest) Reset

func (x *GetLfpStoreRequest) Reset()

func (*GetLfpStoreRequest) String

func (x *GetLfpStoreRequest) String() string

type InsertLfpInventoryRequest

type InsertLfpInventoryRequest struct {

	// Required. The LFP provider account.
	// Format: `accounts/{account}`
	Parent string `protobuf:"bytes,1,opt,name=parent,proto3" json:"parent,omitempty"`
	// Required. The inventory to insert.
	LfpInventory *LfpInventory `protobuf:"bytes,2,opt,name=lfp_inventory,json=lfpInventory,proto3" json:"lfp_inventory,omitempty"`
	// contains filtered or unexported fields
}

Request message for the `InsertLfpInventory` method.

func (*InsertLfpInventoryRequest) Descriptor deprecated

func (*InsertLfpInventoryRequest) Descriptor() ([]byte, []int)

Deprecated: Use InsertLfpInventoryRequest.ProtoReflect.Descriptor instead.

func (*InsertLfpInventoryRequest) GetLfpInventory

func (x *InsertLfpInventoryRequest) GetLfpInventory() *LfpInventory

func (*InsertLfpInventoryRequest) GetParent

func (x *InsertLfpInventoryRequest) GetParent() string

func (*InsertLfpInventoryRequest) ProtoMessage

func (*InsertLfpInventoryRequest) ProtoMessage()

func (*InsertLfpInventoryRequest) ProtoReflect

func (*InsertLfpInventoryRequest) Reset

func (x *InsertLfpInventoryRequest) Reset()

func (*InsertLfpInventoryRequest) String

func (x *InsertLfpInventoryRequest) String() string

type InsertLfpSaleRequest

type InsertLfpSaleRequest struct {

	// Required. The LFP provider account.
	// Format: `accounts/{lfp_partner}`
	Parent string `protobuf:"bytes,1,opt,name=parent,proto3" json:"parent,omitempty"`
	// Required. The sale to insert.
	LfpSale *LfpSale `protobuf:"bytes,2,opt,name=lfp_sale,json=lfpSale,proto3" json:"lfp_sale,omitempty"`
	// contains filtered or unexported fields
}

Request message for the InsertLfpSale method.

func (*InsertLfpSaleRequest) Descriptor deprecated

func (*InsertLfpSaleRequest) Descriptor() ([]byte, []int)

Deprecated: Use InsertLfpSaleRequest.ProtoReflect.Descriptor instead.

func (*InsertLfpSaleRequest) GetLfpSale

func (x *InsertLfpSaleRequest) GetLfpSale() *LfpSale

func (*InsertLfpSaleRequest) GetParent

func (x *InsertLfpSaleRequest) GetParent() string

func (*InsertLfpSaleRequest) ProtoMessage

func (*InsertLfpSaleRequest) ProtoMessage()

func (*InsertLfpSaleRequest) ProtoReflect

func (x *InsertLfpSaleRequest) ProtoReflect() protoreflect.Message

func (*InsertLfpSaleRequest) Reset

func (x *InsertLfpSaleRequest) Reset()

func (*InsertLfpSaleRequest) String

func (x *InsertLfpSaleRequest) String() string

type InsertLfpStoreRequest

type InsertLfpStoreRequest struct {

	// Required. The LFP provider account
	// Format: `accounts/{account}`
	Parent string `protobuf:"bytes,1,opt,name=parent,proto3" json:"parent,omitempty"`
	// Required. The store to insert.
	LfpStore *LfpStore `protobuf:"bytes,2,opt,name=lfp_store,json=lfpStore,proto3" json:"lfp_store,omitempty"`
	// contains filtered or unexported fields
}

Request message for the InsertLfpStore method.

func (*InsertLfpStoreRequest) Descriptor deprecated

func (*InsertLfpStoreRequest) Descriptor() ([]byte, []int)

Deprecated: Use InsertLfpStoreRequest.ProtoReflect.Descriptor instead.

func (*InsertLfpStoreRequest) GetLfpStore

func (x *InsertLfpStoreRequest) GetLfpStore() *LfpStore

func (*InsertLfpStoreRequest) GetParent

func (x *InsertLfpStoreRequest) GetParent() string

func (*InsertLfpStoreRequest) ProtoMessage

func (*InsertLfpStoreRequest) ProtoMessage()

func (*InsertLfpStoreRequest) ProtoReflect

func (x *InsertLfpStoreRequest) ProtoReflect() protoreflect.Message

func (*InsertLfpStoreRequest) Reset

func (x *InsertLfpStoreRequest) Reset()

func (*InsertLfpStoreRequest) String

func (x *InsertLfpStoreRequest) String() string

type LfpInventory

type LfpInventory struct {

	// Output only. Identifier. The name for the `LfpInventory` resource.
	// Format:
	// `accounts/{account}/lfpInventories/{target_merchant}~{store_code}~{offer}`
	Name string `protobuf:"bytes,1,opt,name=name,proto3" json:"name,omitempty"`
	// Required. The Merchant Center ID of the merchant to submit the inventory
	// for.
	TargetAccount int64 `protobuf:"varint,2,opt,name=target_account,json=targetAccount,proto3" json:"target_account,omitempty"`
	// Required. The identifier of the merchant's store. Either the store code
	// inserted through `InsertLfpStore` or the store code in the Business
	// Profile.
	StoreCode string `protobuf:"bytes,3,opt,name=store_code,json=storeCode,proto3" json:"store_code,omitempty"`
	// Required. Immutable. A unique identifier for the product. If both
	// inventories and sales are submitted for a merchant, this id should match
	// for the same product.
	//
	// **Note**: if the merchant sells the same product new and used, they should
	// have different IDs.
	OfferId string `protobuf:"bytes,4,opt,name=offer_id,json=offerId,proto3" json:"offer_id,omitempty"`
	// Required. The [CLDR territory
	// code](https://github.com/unicode-org/cldr/blob/latest/common/main/en.xml)
	// for the country where the product is sold.
	RegionCode string `protobuf:"bytes,5,opt,name=region_code,json=regionCode,proto3" json:"region_code,omitempty"`
	// Required. The two-letter ISO 639-1 language code for the item.
	ContentLanguage string `protobuf:"bytes,6,opt,name=content_language,json=contentLanguage,proto3" json:"content_language,omitempty"`
	// Optional. The Global Trade Item Number of the product.
	Gtin *string `protobuf:"bytes,7,opt,name=gtin,proto3,oneof" json:"gtin,omitempty"`
	// Optional. The current price of the product.
	Price *typepb.Price `protobuf:"bytes,8,opt,name=price,proto3" json:"price,omitempty"`
	// Required. Availability of the product at this store.
	// For accepted attribute values, see the [local product inventory data
	// specification](https://support.google.com/merchants/answer/3061342)
	Availability string `protobuf:"bytes,9,opt,name=availability,proto3" json:"availability,omitempty"`
	// Optional. Quantity of the product available at this store. Must be greater
	// than or equal to zero.
	Quantity *int64 `protobuf:"varint,10,opt,name=quantity,proto3,oneof" json:"quantity,omitempty"`
	// Optional. The time when the inventory is collected. If not set, it will be
	// set to the time when the inventory is submitted.
	CollectionTime *timestamppb.Timestamp `protobuf:"bytes,11,opt,name=collection_time,json=collectionTime,proto3" json:"collection_time,omitempty"`
	// Optional. Supported pickup method for this offer. Unless the value is "not
	// supported", this field must be submitted together with `pickupSla`. For
	// accepted attribute values, see the [local product inventory data
	// specification](https://support.google.com/merchants/answer/3061342).
	PickupMethod *string `protobuf:"bytes,12,opt,name=pickup_method,json=pickupMethod,proto3,oneof" json:"pickup_method,omitempty"`
	// Optional. Expected date that an order will be ready for pickup relative to
	// the order date. Must be submitted together with `pickupMethod`. For
	// accepted attribute values, see the [local product inventory data
	// specification](https://support.google.com/merchants/answer/3061342).
	PickupSla *string `protobuf:"bytes,13,opt,name=pickup_sla,json=pickupSla,proto3,oneof" json:"pickup_sla,omitempty"`
	// Optional. The [feed
	// label](https://developers.google.com/shopping-content/guides/products/feed-labels)
	// for the product. If this is not set, it will default to `regionCode`.
	FeedLabel *string `protobuf:"bytes,14,opt,name=feed_label,json=feedLabel,proto3,oneof" json:"feed_label,omitempty"`
	// contains filtered or unexported fields
}

Local Inventory for the merchant.

func (*LfpInventory) Descriptor deprecated

func (*LfpInventory) Descriptor() ([]byte, []int)

Deprecated: Use LfpInventory.ProtoReflect.Descriptor instead.

func (*LfpInventory) GetAvailability

func (x *LfpInventory) GetAvailability() string

func (*LfpInventory) GetCollectionTime

func (x *LfpInventory) GetCollectionTime() *timestamppb.Timestamp

func (*LfpInventory) GetContentLanguage

func (x *LfpInventory) GetContentLanguage() string

func (*LfpInventory) GetFeedLabel

func (x *LfpInventory) GetFeedLabel() string

func (*LfpInventory) GetGtin

func (x *LfpInventory) GetGtin() string

func (*LfpInventory) GetName

func (x *LfpInventory) GetName() string

func (*LfpInventory) GetOfferId

func (x *LfpInventory) GetOfferId() string

func (*LfpInventory) GetPickupMethod

func (x *LfpInventory) GetPickupMethod() string

func (*LfpInventory) GetPickupSla

func (x *LfpInventory) GetPickupSla() string

func (*LfpInventory) GetPrice

func (x *LfpInventory) GetPrice() *typepb.Price

func (*LfpInventory) GetQuantity

func (x *LfpInventory) GetQuantity() int64

func (*LfpInventory) GetRegionCode

func (x *LfpInventory) GetRegionCode() string

func (*LfpInventory) GetStoreCode

func (x *LfpInventory) GetStoreCode() string

func (*LfpInventory) GetTargetAccount

func (x *LfpInventory) GetTargetAccount() int64

func (*LfpInventory) ProtoMessage

func (*LfpInventory) ProtoMessage()

func (*LfpInventory) ProtoReflect

func (x *LfpInventory) ProtoReflect() protoreflect.Message

func (*LfpInventory) Reset

func (x *LfpInventory) Reset()

func (*LfpInventory) String

func (x *LfpInventory) String() string

type LfpInventoryServiceClient

type LfpInventoryServiceClient interface {
	// Inserts a `LfpInventory` resource for the given target merchant account. If
	// the resource already exists, it will be replaced. The inventory
	// automatically expires after 30 days.
	InsertLfpInventory(ctx context.Context, in *InsertLfpInventoryRequest, opts ...grpc.CallOption) (*LfpInventory, error)
}

LfpInventoryServiceClient is the client API for LfpInventoryService service.

For semantics around ctx use and closing/ending streaming RPCs, please refer to https://pkg.go.dev/google.golang.org/grpc/?tab=doc#ClientConn.NewStream.

type LfpInventoryServiceServer

type LfpInventoryServiceServer interface {
	// Inserts a `LfpInventory` resource for the given target merchant account. If
	// the resource already exists, it will be replaced. The inventory
	// automatically expires after 30 days.
	InsertLfpInventory(context.Context, *InsertLfpInventoryRequest) (*LfpInventory, error)
}

LfpInventoryServiceServer is the server API for LfpInventoryService service. All implementations should embed UnimplementedLfpInventoryServiceServer for forward compatibility

type LfpMerchantState added in v0.19.0

type LfpMerchantState struct {

	// Identifier. The name of the `LfpMerchantState` resource. Format:
	// `accounts/{account}/lfpMerchantStates/{target_merchant}`
	Name string `protobuf:"bytes,1,opt,name=name,proto3" json:"name,omitempty"`
	// Number of [GBPs](https://www.google.com/business/) this merchant has access
	// to.
	LinkedGbps int64 `protobuf:"varint,2,opt,name=linked_gbps,json=linkedGbps,proto3" json:"linked_gbps,omitempty"`
	// Output only. The state per store from the specified merchant. The field
	// will be absent if the merchant has no stores submitted through LFP.
	StoreStates []*LfpMerchantState_LfpStoreState `protobuf:"bytes,3,rep,name=store_states,json=storeStates,proto3" json:"store_states,omitempty"`
	// The inventory statistics for the merchant. The field will be absent if the
	// merchant has no inventory submitted through LFP.
	InventoryStats *LfpMerchantState_InventoryStats `protobuf:"bytes,4,opt,name=inventory_stats,json=inventoryStats,proto3" json:"inventory_stats,omitempty"`
	// Country-specific settings for the merchant.
	CountrySettings []*LfpMerchantState_CountrySettings `protobuf:"bytes,5,rep,name=country_settings,json=countrySettings,proto3" json:"country_settings,omitempty"`
	// contains filtered or unexported fields
}

The LFP state of a merchant.

func (*LfpMerchantState) Descriptor deprecated added in v0.19.0

func (*LfpMerchantState) Descriptor() ([]byte, []int)

Deprecated: Use LfpMerchantState.ProtoReflect.Descriptor instead.

func (*LfpMerchantState) GetCountrySettings added in v0.19.0

func (x *LfpMerchantState) GetCountrySettings() []*LfpMerchantState_CountrySettings

func (*LfpMerchantState) GetInventoryStats added in v0.19.0

func (x *LfpMerchantState) GetInventoryStats() *LfpMerchantState_InventoryStats

func (*LfpMerchantState) GetLinkedGbps added in v0.19.0

func (x *LfpMerchantState) GetLinkedGbps() int64

func (*LfpMerchantState) GetName added in v0.19.0

func (x *LfpMerchantState) GetName() string

func (*LfpMerchantState) GetStoreStates added in v0.19.0

func (x *LfpMerchantState) GetStoreStates() []*LfpMerchantState_LfpStoreState

func (*LfpMerchantState) ProtoMessage added in v0.19.0

func (*LfpMerchantState) ProtoMessage()

func (*LfpMerchantState) ProtoReflect added in v0.19.0

func (x *LfpMerchantState) ProtoReflect() protoreflect.Message

func (*LfpMerchantState) Reset added in v0.19.0

func (x *LfpMerchantState) Reset()

func (*LfpMerchantState) String added in v0.19.0

func (x *LfpMerchantState) String() string

type LfpMerchantStateServiceClient added in v0.19.0

type LfpMerchantStateServiceClient interface {
	// Gets the LFP state of a merchant
	GetLfpMerchantState(ctx context.Context, in *GetLfpMerchantStateRequest, opts ...grpc.CallOption) (*LfpMerchantState, error)
}

LfpMerchantStateServiceClient is the client API for LfpMerchantStateService service.

For semantics around ctx use and closing/ending streaming RPCs, please refer to https://pkg.go.dev/google.golang.org/grpc/?tab=doc#ClientConn.NewStream.

func NewLfpMerchantStateServiceClient added in v0.19.0

func NewLfpMerchantStateServiceClient(cc grpc.ClientConnInterface) LfpMerchantStateServiceClient

type LfpMerchantStateServiceServer added in v0.19.0

type LfpMerchantStateServiceServer interface {
	// Gets the LFP state of a merchant
	GetLfpMerchantState(context.Context, *GetLfpMerchantStateRequest) (*LfpMerchantState, error)
}

LfpMerchantStateServiceServer is the server API for LfpMerchantStateService service. All implementations should embed UnimplementedLfpMerchantStateServiceServer for forward compatibility

type LfpMerchantState_CountrySettings added in v0.19.0

type LfpMerchantState_CountrySettings struct {

	// Required. The [CLDR territory
	// code](https://github.com/unicode-org/cldr/blob/latest/common/main/en.xml)
	// for the country for which these settings are defined.
	RegionCode string `protobuf:"bytes,1,opt,name=region_code,json=regionCode,proto3" json:"region_code,omitempty"`
	// True if this merchant has enabled free local listings in MC.
	FreeLocalListingsEnabled bool `` /* 138-byte string literal not displayed */
	// True if this merchant has enabled local inventory ads in MC.
	LocalInventoryAdsEnabled bool `` /* 138-byte string literal not displayed */
	// Output only. The verification state of this merchant's inventory check.
	InventoryVerificationState LfpMerchantState_CountrySettings_VerificationState `` /* 234-byte string literal not displayed */
	// Output only. The product page type selected by this merchant.
	ProductPageType LfpMerchantState_CountrySettings_ProductPageType `` /* 199-byte string literal not displayed */
	// Output only. The verification state of this merchant's instock serving
	// feature.
	InstockServingVerificationState LfpMerchantState_CountrySettings_VerificationState `` /* 251-byte string literal not displayed */
	// Output only. The verification state of this merchant's pickup serving
	// feature.
	PickupServingVerificationState LfpMerchantState_CountrySettings_VerificationState `` /* 248-byte string literal not displayed */
	// contains filtered or unexported fields
}

Country-specific settings for the merchant.

func (*LfpMerchantState_CountrySettings) Descriptor deprecated added in v0.19.0

func (*LfpMerchantState_CountrySettings) Descriptor() ([]byte, []int)

Deprecated: Use LfpMerchantState_CountrySettings.ProtoReflect.Descriptor instead.

func (*LfpMerchantState_CountrySettings) GetFreeLocalListingsEnabled added in v0.19.0

func (x *LfpMerchantState_CountrySettings) GetFreeLocalListingsEnabled() bool

func (*LfpMerchantState_CountrySettings) GetInstockServingVerificationState added in v0.19.0

func (*LfpMerchantState_CountrySettings) GetInventoryVerificationState added in v0.19.0

func (*LfpMerchantState_CountrySettings) GetLocalInventoryAdsEnabled added in v0.19.0

func (x *LfpMerchantState_CountrySettings) GetLocalInventoryAdsEnabled() bool

func (*LfpMerchantState_CountrySettings) GetPickupServingVerificationState added in v0.19.0

func (*LfpMerchantState_CountrySettings) GetProductPageType added in v0.19.0

func (*LfpMerchantState_CountrySettings) GetRegionCode added in v0.19.0

func (x *LfpMerchantState_CountrySettings) GetRegionCode() string

func (*LfpMerchantState_CountrySettings) ProtoMessage added in v0.19.0

func (*LfpMerchantState_CountrySettings) ProtoMessage()

func (*LfpMerchantState_CountrySettings) ProtoReflect added in v0.19.0

func (*LfpMerchantState_CountrySettings) Reset added in v0.19.0

func (*LfpMerchantState_CountrySettings) String added in v0.19.0

type LfpMerchantState_CountrySettings_ProductPageType added in v0.19.0

type LfpMerchantState_CountrySettings_ProductPageType int32

The possible [product page types](https://support.google.com/merchants/topic/15148370) for a merchant.

const (
	// Product page type unspecified.
	LfpMerchantState_CountrySettings_PRODUCT_PAGE_TYPE_UNSPECIFIED LfpMerchantState_CountrySettings_ProductPageType = 0
	// Google hosted product page.
	LfpMerchantState_CountrySettings_GOOGLE_HOSTED LfpMerchantState_CountrySettings_ProductPageType = 1
	// Merchant hosted product page.
	LfpMerchantState_CountrySettings_MERCHANT_HOSTED LfpMerchantState_CountrySettings_ProductPageType = 2
	// Merchant hosted store specific product page.
	LfpMerchantState_CountrySettings_MERCHANT_HOSTED_STORE_SPECIFIC LfpMerchantState_CountrySettings_ProductPageType = 3
)

func (LfpMerchantState_CountrySettings_ProductPageType) Descriptor added in v0.19.0

func (LfpMerchantState_CountrySettings_ProductPageType) Enum added in v0.19.0

func (LfpMerchantState_CountrySettings_ProductPageType) EnumDescriptor deprecated added in v0.19.0

Deprecated: Use LfpMerchantState_CountrySettings_ProductPageType.Descriptor instead.

func (LfpMerchantState_CountrySettings_ProductPageType) Number added in v0.19.0

func (LfpMerchantState_CountrySettings_ProductPageType) String added in v0.19.0

func (LfpMerchantState_CountrySettings_ProductPageType) Type added in v0.19.0

type LfpMerchantState_CountrySettings_VerificationState added in v0.19.0

type LfpMerchantState_CountrySettings_VerificationState int32

The possible verification states for different merchant programs.

const (
	// Verification state unspecified.
	LfpMerchantState_CountrySettings_VERIFICATION_STATE_UNSPECIFIED LfpMerchantState_CountrySettings_VerificationState = 0
	// Verification state not approved.
	LfpMerchantState_CountrySettings_VERIFICATION_STATE_NOT_APPROVED LfpMerchantState_CountrySettings_VerificationState = 1
	// Verification state in progress.
	LfpMerchantState_CountrySettings_VERIFICATION_STATE_IN_PROGRESS LfpMerchantState_CountrySettings_VerificationState = 2
	// Verification state approved.
	LfpMerchantState_CountrySettings_VERIFICATION_STATE_APPROVED LfpMerchantState_CountrySettings_VerificationState = 3
)

func (LfpMerchantState_CountrySettings_VerificationState) Descriptor added in v0.19.0

func (LfpMerchantState_CountrySettings_VerificationState) Enum added in v0.19.0

func (LfpMerchantState_CountrySettings_VerificationState) EnumDescriptor deprecated added in v0.19.0

Deprecated: Use LfpMerchantState_CountrySettings_VerificationState.Descriptor instead.

func (LfpMerchantState_CountrySettings_VerificationState) Number added in v0.19.0

func (LfpMerchantState_CountrySettings_VerificationState) String added in v0.19.0

func (LfpMerchantState_CountrySettings_VerificationState) Type added in v0.19.0

type LfpMerchantState_InventoryStats added in v0.19.0

type LfpMerchantState_InventoryStats struct {

	// Number of entries (understanding entry as a pair of product and store)
	// that were built based on provided inventories/sales and submitted to
	// Google.
	SubmittedEntries int64 `protobuf:"varint,1,opt,name=submitted_entries,json=submittedEntries,proto3" json:"submitted_entries,omitempty"`
	// Number of submitted in stock entries.
	SubmittedInStockEntries int64 `` /* 135-byte string literal not displayed */
	// Number of entries that were built based on provided
	// inventories/sales and couldn't be submitted to Google due to errors like
	// missing product.
	UnsubmittedEntries int64 `protobuf:"varint,3,opt,name=unsubmitted_entries,json=unsubmittedEntries,proto3" json:"unsubmitted_entries,omitempty"`
	// Number of products from provided inventories/sales that were created from
	// matches to existing online products provided by the merchant or to the
	// Google catalog.
	SubmittedProducts int64 `protobuf:"varint,4,opt,name=submitted_products,json=submittedProducts,proto3" json:"submitted_products,omitempty"`
	// contains filtered or unexported fields
}

The inventory statistics for a merchant.

func (*LfpMerchantState_InventoryStats) Descriptor deprecated added in v0.19.0

func (*LfpMerchantState_InventoryStats) Descriptor() ([]byte, []int)

Deprecated: Use LfpMerchantState_InventoryStats.ProtoReflect.Descriptor instead.

func (*LfpMerchantState_InventoryStats) GetSubmittedEntries added in v0.19.0

func (x *LfpMerchantState_InventoryStats) GetSubmittedEntries() int64

func (*LfpMerchantState_InventoryStats) GetSubmittedInStockEntries added in v0.19.0

func (x *LfpMerchantState_InventoryStats) GetSubmittedInStockEntries() int64

func (*LfpMerchantState_InventoryStats) GetSubmittedProducts added in v0.19.0

func (x *LfpMerchantState_InventoryStats) GetSubmittedProducts() int64

func (*LfpMerchantState_InventoryStats) GetUnsubmittedEntries added in v0.19.0

func (x *LfpMerchantState_InventoryStats) GetUnsubmittedEntries() int64

func (*LfpMerchantState_InventoryStats) ProtoMessage added in v0.19.0

func (*LfpMerchantState_InventoryStats) ProtoMessage()

func (*LfpMerchantState_InventoryStats) ProtoReflect added in v0.19.0

func (*LfpMerchantState_InventoryStats) Reset added in v0.19.0

func (*LfpMerchantState_InventoryStats) String added in v0.19.0

type LfpMerchantState_LfpStoreState added in v0.19.0

type LfpMerchantState_LfpStoreState struct {

	// Required. Immutable. The identifier of this store.
	StoreCode string `protobuf:"bytes,1,opt,name=store_code,json=storeCode,proto3" json:"store_code,omitempty"`
	// Output only. The store matching state.
	MatchingState LfpMerchantState_LfpStoreState_StoreMatchingState `` /* 192-byte string literal not displayed */
	// The hint of why the matching has failed (only set if matching_state is
	// FAILED).
	MatchingStateHint string `protobuf:"bytes,3,opt,name=matching_state_hint,json=matchingStateHint,proto3" json:"matching_state_hint,omitempty"`
	// contains filtered or unexported fields
}

The state of a specific merchant's store.

func (*LfpMerchantState_LfpStoreState) Descriptor deprecated added in v0.19.0

func (*LfpMerchantState_LfpStoreState) Descriptor() ([]byte, []int)

Deprecated: Use LfpMerchantState_LfpStoreState.ProtoReflect.Descriptor instead.

func (*LfpMerchantState_LfpStoreState) GetMatchingState added in v0.19.0

func (*LfpMerchantState_LfpStoreState) GetMatchingStateHint added in v0.19.0

func (x *LfpMerchantState_LfpStoreState) GetMatchingStateHint() string

func (*LfpMerchantState_LfpStoreState) GetStoreCode added in v0.19.0

func (x *LfpMerchantState_LfpStoreState) GetStoreCode() string

func (*LfpMerchantState_LfpStoreState) ProtoMessage added in v0.19.0

func (*LfpMerchantState_LfpStoreState) ProtoMessage()

func (*LfpMerchantState_LfpStoreState) ProtoReflect added in v0.19.0

func (*LfpMerchantState_LfpStoreState) Reset added in v0.19.0

func (x *LfpMerchantState_LfpStoreState) Reset()

func (*LfpMerchantState_LfpStoreState) String added in v0.19.0

type LfpMerchantState_LfpStoreState_StoreMatchingState added in v0.19.0

type LfpMerchantState_LfpStoreState_StoreMatchingState int32

The state of matching `LfpStore` to a Google Business Profile listing.

const (
	// Store matching state unspecified.
	LfpMerchantState_LfpStoreState_STORE_MATCHING_STATE_UNSPECIFIED LfpMerchantState_LfpStoreState_StoreMatchingState = 0
	// The `LfpStore` is successfully matched with a Google Business Profile
	// store.
	LfpMerchantState_LfpStoreState_STORE_MATCHING_STATE_MATCHED LfpMerchantState_LfpStoreState_StoreMatchingState = 1
	// The `LfpStore` is not matched with a Google Business Profile store.
	LfpMerchantState_LfpStoreState_STORE_MATCHING_STATE_FAILED LfpMerchantState_LfpStoreState_StoreMatchingState = 2
)

func (LfpMerchantState_LfpStoreState_StoreMatchingState) Descriptor added in v0.19.0

func (LfpMerchantState_LfpStoreState_StoreMatchingState) Enum added in v0.19.0

func (LfpMerchantState_LfpStoreState_StoreMatchingState) EnumDescriptor deprecated added in v0.19.0

Deprecated: Use LfpMerchantState_LfpStoreState_StoreMatchingState.Descriptor instead.

func (LfpMerchantState_LfpStoreState_StoreMatchingState) Number added in v0.19.0

func (LfpMerchantState_LfpStoreState_StoreMatchingState) String added in v0.19.0

func (LfpMerchantState_LfpStoreState_StoreMatchingState) Type added in v0.19.0

type LfpSale

type LfpSale struct {

	// Output only. Identifier. The name of the `LfpSale` resource.
	// Format:
	// `accounts/{account}/lfpSales/{sale}`
	Name string `protobuf:"bytes,1,opt,name=name,proto3" json:"name,omitempty"`
	// Required. The Merchant Center ID of the merchant to submit the sale for.
	TargetAccount int64 `protobuf:"varint,2,opt,name=target_account,json=targetAccount,proto3" json:"target_account,omitempty"`
	// Required. The identifier of the merchant's store. Either a `storeCode`
	// inserted through the API or the code of the store in the Business Profile.
	StoreCode string `protobuf:"bytes,3,opt,name=store_code,json=storeCode,proto3" json:"store_code,omitempty"`
	// Required. A unique identifier for the product. If both inventories and
	// sales are submitted for a merchant, this id should match for the same
	// product.
	//
	// **Note**: if the merchant sells the same product new and used, they should
	// have different IDs.
	OfferId string `protobuf:"bytes,4,opt,name=offer_id,json=offerId,proto3" json:"offer_id,omitempty"`
	// Required. The [CLDR territory
	// code](https://github.com/unicode-org/cldr/blob/latest/common/main/en.xml)
	// for the country where the product is sold.
	RegionCode string `protobuf:"bytes,5,opt,name=region_code,json=regionCode,proto3" json:"region_code,omitempty"`
	// Required. The two-letter ISO 639-1 language code for the item.
	ContentLanguage string `protobuf:"bytes,6,opt,name=content_language,json=contentLanguage,proto3" json:"content_language,omitempty"`
	// Required. The Global Trade Item Number of the sold product.
	Gtin string `protobuf:"bytes,7,opt,name=gtin,proto3" json:"gtin,omitempty"`
	// Required. The unit price of the product.
	Price *typepb.Price `protobuf:"bytes,8,opt,name=price,proto3" json:"price,omitempty"`
	// Required. The relative change of the available quantity. Negative for items
	// returned.
	Quantity int64 `protobuf:"varint,9,opt,name=quantity,proto3" json:"quantity,omitempty"`
	// Required. The timestamp for the sale.
	SaleTime *timestamppb.Timestamp `protobuf:"bytes,10,opt,name=sale_time,json=saleTime,proto3" json:"sale_time,omitempty"`
	// Output only. System generated globally unique ID for the `LfpSale`.
	Uid *string `protobuf:"bytes,11,opt,name=uid,proto3,oneof" json:"uid,omitempty"`
	// Optional. The [feed
	// label](https://developers.google.com/shopping-content/guides/products/feed-labels)
	// for the product. If this is not set, it will default to `regionCode`.
	FeedLabel *string `protobuf:"bytes,12,opt,name=feed_label,json=feedLabel,proto3,oneof" json:"feed_label,omitempty"`
	// contains filtered or unexported fields
}

A sale for the merchant.

func (*LfpSale) Descriptor deprecated

func (*LfpSale) Descriptor() ([]byte, []int)

Deprecated: Use LfpSale.ProtoReflect.Descriptor instead.

func (*LfpSale) GetContentLanguage

func (x *LfpSale) GetContentLanguage() string

func (*LfpSale) GetFeedLabel

func (x *LfpSale) GetFeedLabel() string

func (*LfpSale) GetGtin

func (x *LfpSale) GetGtin() string

func (*LfpSale) GetName

func (x *LfpSale) GetName() string

func (*LfpSale) GetOfferId

func (x *LfpSale) GetOfferId() string

func (*LfpSale) GetPrice

func (x *LfpSale) GetPrice() *typepb.Price

func (*LfpSale) GetQuantity

func (x *LfpSale) GetQuantity() int64

func (*LfpSale) GetRegionCode

func (x *LfpSale) GetRegionCode() string

func (*LfpSale) GetSaleTime

func (x *LfpSale) GetSaleTime() *timestamppb.Timestamp

func (*LfpSale) GetStoreCode

func (x *LfpSale) GetStoreCode() string

func (*LfpSale) GetTargetAccount

func (x *LfpSale) GetTargetAccount() int64

func (*LfpSale) GetUid

func (x *LfpSale) GetUid() string

func (*LfpSale) ProtoMessage

func (*LfpSale) ProtoMessage()

func (*LfpSale) ProtoReflect

func (x *LfpSale) ProtoReflect() protoreflect.Message

func (*LfpSale) Reset

func (x *LfpSale) Reset()

func (*LfpSale) String

func (x *LfpSale) String() string

type LfpSaleServiceClient

type LfpSaleServiceClient interface {
	// Inserts a `LfpSale` for the given merchant.
	InsertLfpSale(ctx context.Context, in *InsertLfpSaleRequest, opts ...grpc.CallOption) (*LfpSale, error)
}

LfpSaleServiceClient is the client API for LfpSaleService service.

For semantics around ctx use and closing/ending streaming RPCs, please refer to https://pkg.go.dev/google.golang.org/grpc/?tab=doc#ClientConn.NewStream.

type LfpSaleServiceServer

type LfpSaleServiceServer interface {
	// Inserts a `LfpSale` for the given merchant.
	InsertLfpSale(context.Context, *InsertLfpSaleRequest) (*LfpSale, error)
}

LfpSaleServiceServer is the server API for LfpSaleService service. All implementations should embed UnimplementedLfpSaleServiceServer for forward compatibility

type LfpStore

type LfpStore struct {

	// Output only. Identifier. The name of the `LfpStore` resource.
	// Format: `accounts/{account}/lfpStores/{target_merchant}~{store_code}`
	Name string `protobuf:"bytes,1,opt,name=name,proto3" json:"name,omitempty"`
	// Required. The Merchant Center id of the merchant to submit the store for.
	TargetAccount int64 `protobuf:"varint,2,opt,name=target_account,json=targetAccount,proto3" json:"target_account,omitempty"`
	// Required. Immutable. A store identifier that is unique for the target
	// merchant.
	StoreCode string `protobuf:"bytes,3,opt,name=store_code,json=storeCode,proto3" json:"store_code,omitempty"`
	// Required. The street address of the store.
	// Example: 1600 Amphitheatre Pkwy, Mountain View, CA 94043, USA.
	StoreAddress string `protobuf:"bytes,4,opt,name=store_address,json=storeAddress,proto3" json:"store_address,omitempty"`
	// Optional. The merchant or store name.
	StoreName *string `protobuf:"bytes,5,opt,name=store_name,json=storeName,proto3,oneof" json:"store_name,omitempty"`
	// Optional. The store phone number in
	// [E.164](https://en.wikipedia.org/wiki/E.164) format. Example:
	// `+15556767888`
	PhoneNumber *string `protobuf:"bytes,6,opt,name=phone_number,json=phoneNumber,proto3,oneof" json:"phone_number,omitempty"`
	// Optional. The website URL for the store or merchant.
	WebsiteUri *string `protobuf:"bytes,7,opt,name=website_uri,json=websiteUri,proto3,oneof" json:"website_uri,omitempty"`
	// Optional. [Google My Business category
	// id](https://gcid-explorer.corp.google.com/static/gcid.html).
	GcidCategory []string `protobuf:"bytes,8,rep,name=gcid_category,json=gcidCategory,proto3" json:"gcid_category,omitempty"`
	// Optional. The [Google Place
	// Id](https://developers.google.com/maps/documentation/places/web-service/place-id#id-overview)
	// of the store location.
	PlaceId *string `protobuf:"bytes,9,opt,name=place_id,json=placeId,proto3,oneof" json:"place_id,omitempty"`
	// Optional. Output only. The state of matching to a Google Business Profile.
	// See
	// [matchingStateHint][google.shopping.merchant.lfp.v1beta.LfpStore.matching_state_hint]
	// for further details if no match is found.
	MatchingState LfpStore_StoreMatchingState `` /* 171-byte string literal not displayed */
	// Optional. Output only. The hint of why the matching has failed. This is
	// only set when
	// [matchingState][google.shopping.merchant.lfp.v1beta.LfpStore.matching_state]=`STORE_MATCHING_STATE_FAILED`.
	//
	// Possible values are:
	//
	// - "`linked-store-not-found`": There aren't any Google Business
	// Profile stores available for matching.
	// - "`store-match-not-found`": The provided `LfpStore` couldn't be matched to
	// any of the connected Google Business Profile stores. Merchant Center
	// account is connected correctly and stores are available on Google Business
	// Profile, but the `LfpStore` location address does not match with Google
	// Business Profile stores' addresses. Update the `LfpStore` address or Google
	// Business Profile store address to match correctly.
	// - "`store-match-unverified`": The provided `LfpStore` couldn't be matched
	// to any of the connected Google Business Profile stores, as the matched
	// Google Business Profile store is unverified. Go through the Google Business
	// Profile verification process to match correctly.
	MatchingStateHint *string `protobuf:"bytes,11,opt,name=matching_state_hint,json=matchingStateHint,proto3,oneof" json:"matching_state_hint,omitempty"`
	// contains filtered or unexported fields
}

A store for the merchant. This will be used to match to a store under the Google Business Profile of the target merchant. If a matching store can't be found, the inventories or sales submitted with the store code will not be used.

func (*LfpStore) Descriptor deprecated

func (*LfpStore) Descriptor() ([]byte, []int)

Deprecated: Use LfpStore.ProtoReflect.Descriptor instead.

func (*LfpStore) GetGcidCategory

func (x *LfpStore) GetGcidCategory() []string

func (*LfpStore) GetMatchingState

func (x *LfpStore) GetMatchingState() LfpStore_StoreMatchingState

func (*LfpStore) GetMatchingStateHint

func (x *LfpStore) GetMatchingStateHint() string

func (*LfpStore) GetName

func (x *LfpStore) GetName() string

func (*LfpStore) GetPhoneNumber

func (x *LfpStore) GetPhoneNumber() string

func (*LfpStore) GetPlaceId

func (x *LfpStore) GetPlaceId() string

func (*LfpStore) GetStoreAddress

func (x *LfpStore) GetStoreAddress() string

func (*LfpStore) GetStoreCode

func (x *LfpStore) GetStoreCode() string

func (*LfpStore) GetStoreName

func (x *LfpStore) GetStoreName() string

func (*LfpStore) GetTargetAccount

func (x *LfpStore) GetTargetAccount() int64

func (*LfpStore) GetWebsiteUri

func (x *LfpStore) GetWebsiteUri() string

func (*LfpStore) ProtoMessage

func (*LfpStore) ProtoMessage()

func (*LfpStore) ProtoReflect

func (x *LfpStore) ProtoReflect() protoreflect.Message

func (*LfpStore) Reset

func (x *LfpStore) Reset()

func (*LfpStore) String

func (x *LfpStore) String() string

type LfpStoreServiceClient

type LfpStoreServiceClient interface {
	// Retrieves information about a store.
	GetLfpStore(ctx context.Context, in *GetLfpStoreRequest, opts ...grpc.CallOption) (*LfpStore, error)
	// Inserts a store for the target merchant. If the store with the same store
	// code already exists, it will be replaced.
	InsertLfpStore(ctx context.Context, in *InsertLfpStoreRequest, opts ...grpc.CallOption) (*LfpStore, error)
	// Deletes a store for a target merchant.
	DeleteLfpStore(ctx context.Context, in *DeleteLfpStoreRequest, opts ...grpc.CallOption) (*emptypb.Empty, error)
	// Lists the stores of the target merchant, specified by the filter in
	// `ListLfpStoresRequest`.
	ListLfpStores(ctx context.Context, in *ListLfpStoresRequest, opts ...grpc.CallOption) (*ListLfpStoresResponse, error)
}

LfpStoreServiceClient is the client API for LfpStoreService service.

For semantics around ctx use and closing/ending streaming RPCs, please refer to https://pkg.go.dev/google.golang.org/grpc/?tab=doc#ClientConn.NewStream.

type LfpStoreServiceServer

type LfpStoreServiceServer interface {
	// Retrieves information about a store.
	GetLfpStore(context.Context, *GetLfpStoreRequest) (*LfpStore, error)
	// Inserts a store for the target merchant. If the store with the same store
	// code already exists, it will be replaced.
	InsertLfpStore(context.Context, *InsertLfpStoreRequest) (*LfpStore, error)
	// Deletes a store for a target merchant.
	DeleteLfpStore(context.Context, *DeleteLfpStoreRequest) (*emptypb.Empty, error)
	// Lists the stores of the target merchant, specified by the filter in
	// `ListLfpStoresRequest`.
	ListLfpStores(context.Context, *ListLfpStoresRequest) (*ListLfpStoresResponse, error)
}

LfpStoreServiceServer is the server API for LfpStoreService service. All implementations should embed UnimplementedLfpStoreServiceServer for forward compatibility

type LfpStore_StoreMatchingState

type LfpStore_StoreMatchingState int32

The state of matching `LfpStore` to a Google Business Profile.

const (
	// Store matching state unspecified.
	LfpStore_STORE_MATCHING_STATE_UNSPECIFIED LfpStore_StoreMatchingState = 0
	// The `LfpStore` is successfully matched with a Google Business Profile
	// store.
	LfpStore_STORE_MATCHING_STATE_MATCHED LfpStore_StoreMatchingState = 1
	// The `LfpStore` is not matched with a Google Business Profile store.
	LfpStore_STORE_MATCHING_STATE_FAILED LfpStore_StoreMatchingState = 2
)

func (LfpStore_StoreMatchingState) Descriptor

func (LfpStore_StoreMatchingState) Enum

func (LfpStore_StoreMatchingState) EnumDescriptor deprecated

func (LfpStore_StoreMatchingState) EnumDescriptor() ([]byte, []int)

Deprecated: Use LfpStore_StoreMatchingState.Descriptor instead.

func (LfpStore_StoreMatchingState) Number

func (LfpStore_StoreMatchingState) String

func (LfpStore_StoreMatchingState) Type

type ListLfpStoresRequest

type ListLfpStoresRequest struct {

	// Required. The LFP partner.
	// Format: `accounts/{account}`
	Parent string `protobuf:"bytes,1,opt,name=parent,proto3" json:"parent,omitempty"`
	// Required. The Merchant Center id of the merchant to list stores for.
	TargetAccount int64 `protobuf:"varint,2,opt,name=target_account,json=targetAccount,proto3" json:"target_account,omitempty"`
	// Optional. The maximum number of `LfpStore` resources for the given account
	// to return. The service returns fewer than this value if the number of
	// stores for the given account is less than the `pageSize`. The default value
	// is 250. The maximum value is 1000; If a value higher than the maximum is
	// specified, then the `pageSize` will default to the maximum.
	PageSize int32 `protobuf:"varint,3,opt,name=page_size,json=pageSize,proto3" json:"page_size,omitempty"`
	// Optional. A page token, received from a previous `ListLfpStoresRequest`
	// call. Provide the page token to retrieve the subsequent page. When
	// paginating, all other parameters provided to `ListLfpStoresRequest` must
	// match the call that provided the page token. The token returned as
	// [nextPageToken][google.shopping.merchant.lfp.v1beta.ListLfpStoresResponse.next_page_token]
	// in the response to the previous request.
	PageToken string `protobuf:"bytes,4,opt,name=page_token,json=pageToken,proto3" json:"page_token,omitempty"`
	// contains filtered or unexported fields
}

Request message for the ListLfpStores method.

func (*ListLfpStoresRequest) Descriptor deprecated

func (*ListLfpStoresRequest) Descriptor() ([]byte, []int)

Deprecated: Use ListLfpStoresRequest.ProtoReflect.Descriptor instead.

func (*ListLfpStoresRequest) GetPageSize

func (x *ListLfpStoresRequest) GetPageSize() int32

func (*ListLfpStoresRequest) GetPageToken

func (x *ListLfpStoresRequest) GetPageToken() string

func (*ListLfpStoresRequest) GetParent

func (x *ListLfpStoresRequest) GetParent() string

func (*ListLfpStoresRequest) GetTargetAccount

func (x *ListLfpStoresRequest) GetTargetAccount() int64

func (*ListLfpStoresRequest) ProtoMessage

func (*ListLfpStoresRequest) ProtoMessage()

func (*ListLfpStoresRequest) ProtoReflect

func (x *ListLfpStoresRequest) ProtoReflect() protoreflect.Message

func (*ListLfpStoresRequest) Reset

func (x *ListLfpStoresRequest) Reset()

func (*ListLfpStoresRequest) String

func (x *ListLfpStoresRequest) String() string

type ListLfpStoresResponse

type ListLfpStoresResponse struct {

	// The stores from the specified merchant.
	LfpStores []*LfpStore `protobuf:"bytes,1,rep,name=lfp_stores,json=lfpStores,proto3" json:"lfp_stores,omitempty"`
	// A token, which can be sent as `pageToken` to retrieve the next page.
	// If this field is omitted, there are no subsequent pages.
	NextPageToken string `protobuf:"bytes,2,opt,name=next_page_token,json=nextPageToken,proto3" json:"next_page_token,omitempty"`
	// contains filtered or unexported fields
}

Response message for the ListLfpStores method.

func (*ListLfpStoresResponse) Descriptor deprecated

func (*ListLfpStoresResponse) Descriptor() ([]byte, []int)

Deprecated: Use ListLfpStoresResponse.ProtoReflect.Descriptor instead.

func (*ListLfpStoresResponse) GetLfpStores

func (x *ListLfpStoresResponse) GetLfpStores() []*LfpStore

func (*ListLfpStoresResponse) GetNextPageToken

func (x *ListLfpStoresResponse) GetNextPageToken() string

func (*ListLfpStoresResponse) ProtoMessage

func (*ListLfpStoresResponse) ProtoMessage()

func (*ListLfpStoresResponse) ProtoReflect

func (x *ListLfpStoresResponse) ProtoReflect() protoreflect.Message

func (*ListLfpStoresResponse) Reset

func (x *ListLfpStoresResponse) Reset()

func (*ListLfpStoresResponse) String

func (x *ListLfpStoresResponse) String() string

type UnimplementedLfpInventoryServiceServer

type UnimplementedLfpInventoryServiceServer struct {
}

UnimplementedLfpInventoryServiceServer should be embedded to have forward compatible implementations.

func (UnimplementedLfpInventoryServiceServer) InsertLfpInventory

type UnimplementedLfpMerchantStateServiceServer added in v0.19.0

type UnimplementedLfpMerchantStateServiceServer struct {
}

UnimplementedLfpMerchantStateServiceServer should be embedded to have forward compatible implementations.

func (UnimplementedLfpMerchantStateServiceServer) GetLfpMerchantState added in v0.19.0

type UnimplementedLfpSaleServiceServer

type UnimplementedLfpSaleServiceServer struct {
}

UnimplementedLfpSaleServiceServer should be embedded to have forward compatible implementations.

func (UnimplementedLfpSaleServiceServer) InsertLfpSale

type UnimplementedLfpStoreServiceServer

type UnimplementedLfpStoreServiceServer struct {
}

UnimplementedLfpStoreServiceServer should be embedded to have forward compatible implementations.

func (UnimplementedLfpStoreServiceServer) DeleteLfpStore

func (UnimplementedLfpStoreServiceServer) GetLfpStore

func (UnimplementedLfpStoreServiceServer) InsertLfpStore

func (UnimplementedLfpStoreServiceServer) ListLfpStores

type UnsafeLfpInventoryServiceServer added in v0.21.0

type UnsafeLfpInventoryServiceServer interface {
	// contains filtered or unexported methods
}

UnsafeLfpInventoryServiceServer may be embedded to opt out of forward compatibility for this service. Use of this interface is not recommended, as added methods to LfpInventoryServiceServer will result in compilation errors.

type UnsafeLfpMerchantStateServiceServer added in v0.21.0

type UnsafeLfpMerchantStateServiceServer interface {
	// contains filtered or unexported methods
}

UnsafeLfpMerchantStateServiceServer may be embedded to opt out of forward compatibility for this service. Use of this interface is not recommended, as added methods to LfpMerchantStateServiceServer will result in compilation errors.

type UnsafeLfpSaleServiceServer added in v0.21.0

type UnsafeLfpSaleServiceServer interface {
	// contains filtered or unexported methods
}

UnsafeLfpSaleServiceServer may be embedded to opt out of forward compatibility for this service. Use of this interface is not recommended, as added methods to LfpSaleServiceServer will result in compilation errors.

type UnsafeLfpStoreServiceServer added in v0.21.0

type UnsafeLfpStoreServiceServer interface {
	// contains filtered or unexported methods
}

UnsafeLfpStoreServiceServer may be embedded to opt out of forward compatibility for this service. Use of this interface is not recommended, as added methods to LfpStoreServiceServer will result in compilation errors.

Jump to